#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const utils_1 = require("./utils");
const glob_1 = require("glob");
const [executor, ignoredBin, script, ...args] = process.argv;
const spawnScript = () => {
    try {
        const path = require.resolve(path_1.join(__dirname, "./scripts", script));
        const res = utils_1.run(executor, [path, ...args], true);
        return res.signal ? handleSignal(res.signal) : utils_1.exit(res.status);
    }
    catch (error) {
        throw new Error(`Unknown script "${script}".`);
    }
};
const handleSignal = (signal) => {
    const msg = "'${script}' failed because the process exited";
    if (signal === "SIGKILL" || signal === "SIGTERM")
        console.log(msg);
    return utils_1.exit(1);
};
if (script)
    spawnScript();
else {
    const path = path_1.join(__dirname, "scripts/");
    const commands = glob_1.sync(path_1.join(__dirname, "scripts", "*"))
        .filter((s) => !s.endsWith(".ts") && !s.endsWith(".map"))
        .map((s) => s.replace(path, "").replace(/\.js$/, ""))
        .join("\n  ")
        .trim();
    console.log(`\n
Usage: ${ignoredBin} [command] [options]
Commands:
  ${commands}
Options:
  Script-dependent, the args you pass will be forwarded to the respective tool.
\n`);
}
//# sourceMappingURL=index.js.map