"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.exit = exports.resolveSelf = exports.resolveBin = exports.config = exports.hasFile = void 0;
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const path_1 = require("path");
const read_pkg_up_1 = __importDefault(require("read-pkg-up"));
const which_1 = require("which");
const pkg = read_pkg_up_1.default.sync({ cwd: fs_1.realpathSync(process.cwd()) });
const appDir = path_1.dirname((pkg || { path: "" }).path);
const empty = Buffer.from("", "utf8");
const fromRoot = (...p) => path_1.join(appDir, ...p);
const hasFile = (...p) => fs_1.existsSync(fromRoot(...p));
exports.hasFile = hasFile;
const config = (p) => path_1.join(__dirname, `./config/${p}`).replace(process.cwd(), ".");
exports.config = config;
const resolveBin = (mod, { exec = mod, cwd = process.cwd() } = {}) => {
    let path;
    try {
        path = fs_1.realpathSync(which_1.sync(exec));
    }
    catch {
        // ignore
    }
    try {
        const modPath = require.resolve(`${mod}/package.json`);
        // eslint-disable-next-line
        const { bin } = require(modPath);
        const binPath = path_1.join(path_1.dirname(modPath), typeof bin === "string" ? bin : bin[exec]);
        return binPath === path ? exec : binPath.replace(cwd, ".");
    }
    catch (err) {
        if (path)
            return exec;
        throw err;
    }
};
exports.resolveBin = resolveBin;
const resolveSelf = () => pkg && pkg.packageJson.name === "skripts"
    ? `node ${require.resolve("./").replace(process.cwd(), ".")}`
    : exports.resolveBin("skripts");
exports.resolveSelf = resolveSelf;
const exit = (s) => process.exit(s === null ? -1 : s);
exports.exit = exit;
const run = (cmd, args, verbose = false, env = {}) => {
    try {
        if (verbose)
            console.log(cmd, args);
        return child_process_1.spawnSync(cmd, args, {
            env: { ...process.env, ...env },
            stdio: "inherit",
        });
    }
    catch (e) {
        console.error(e.message || e);
        return {
            pid: 0,
            output: [],
            stdout: empty,
            stderr: empty,
            signal: null,
            status: 1,
        };
    }
};
exports.run = run;
//# sourceMappingURL=utils.js.map